diff roundup/mailgw.py @ 337:8cd545738d8e

Features: . [SF#467129] Lossage when username=e-mail-address . [SF#473123] Change message generation for author . MailGW now moves 'resolved' to 'chatting' on receiving e-mail for an issue.
author Richard Jones <richard@users.sourceforge.net>
date Tue, 30 Oct 2001 00:54:45 +0000
parents 256776bfdfc5
children 4e39e26ede38
line wrap: on
line diff
--- a/roundup/mailgw.py	Mon Oct 29 23:55:44 2001 +0000
+++ b/roundup/mailgw.py	Tue Oct 30 00:54:45 2001 +0000
@@ -72,7 +72,7 @@
 an exception, the original message is bounced back to the sender with the
 explanatory message given in the exception. 
 
-$Id: mailgw.py,v 1.25 2001-10-28 23:22:28 richard Exp $
+$Id: mailgw.py,v 1.26 2001-10-30 00:54:45 richard Exp $
 '''
 
 
@@ -365,17 +365,20 @@
             messages.append(message_id)
             props['messages'] = messages
 
-            # if the message is currently 'unread', then set it to 'chatting'
+            # if the message is currently 'unread' or 'resolved', then set
+            # it to 'chatting'
             if properties.has_key('status'):
                 try:
                     # determine the id of 'unread' and 'chatting'
                     unread_id = self.db.status.lookup('unread')
+                    resolved_id = self.db.status.lookup('resolved')
                     chatting_id = self.db.status.lookup('chatting')
                 except KeyError:
                     pass
                 else:
                     if (not props.has_key('status') or
-                            props['status'] == unread_id):
+                            props['status'] == unread_id or
+                            props['status'] == resolved_id):
                         props['status'] = chatting_id
 
             cl.set(nodeid, **props)
@@ -441,6 +444,9 @@
 
 #
 # $Log: not supported by cvs2svn $
+# Revision 1.25  2001/10/28 23:22:28  richard
+# fixed bug #474749 ] Indentations lost
+#
 # Revision 1.24  2001/10/23 22:57:52  richard
 # Fix unread->chatting auto transition, thanks Roch'e
 #
@@ -365,17 +365,20 @@
             if properties.has_key('status'):
                 try:
-                    # determine the id of 'unread' and 'chatting'
+                    # determine the id of 'unread', 'resolved' and 'chatting'
                     unread_id = self.db.status.lookup('unread')

Roundup Issue Tracker: http://roundup-tracker.org/